diff artifacts/src/main/java/org/dive4elements/river/artifacts/states/MinMaxState.java @ 5867:59ff03ff48f1

River artifacts: Renamed FLYSArtifact(Collection) to D4EArtifact(Collection).
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 28 Apr 2013 15:23:01 +0200
parents 4897a58c8746
children af13ceeba52a
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/artifacts/states/MinMaxState.java	Sun Apr 28 15:14:30 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/artifacts/states/MinMaxState.java	Sun Apr 28 15:23:01 2013 +0200
@@ -20,7 +20,7 @@
 
 import org.dive4elements.artifactdatabase.ProtocolUtils;
 
-import org.dive4elements.river.artifacts.FLYSArtifact;
+import org.dive4elements.river.artifacts.D4EArtifact;
 
 
 /**
@@ -40,7 +40,7 @@
         CallContext    context,
         Element        select
     ) {
-        FLYSArtifact flys = (FLYSArtifact) artifact;
+        D4EArtifact flys = (D4EArtifact) artifact;
 
         select.setAttributeNS(
             ArtifactNamespaceContext.NAMESPACE_URI,
@@ -112,7 +112,7 @@
      * by the user is returned as string. Otherwise, the absolute minimum and
      * maximum are returned.
      *
-     * @param artifact The FLYSArtifact.
+     * @param artifact The D4EArtifact.
      * @param name The name of the parameter.
      *
      * @return a string array [min,max] that contains the minimum and maximum
@@ -134,13 +134,13 @@
      * Returns a string array with minimum and maximum inserted by the user as
      * [min,max].
      *
      * @param artifact The FLYSArtifact that stores the parameter.
      * @param name The name of the parameter for raw min/max value string.
      *
      * @return a string array [min,max].
      */
     protected String[] getMinMaxByParameter(Artifact artifact, String name) {
-        FLYSArtifact flys     = (FLYSArtifact) artifact;
+        D4EArtifact flys     = (D4EArtifact) artifact;
         String       rawValue = flys.getDataAsString(name);
 
         if (rawValue == null) {
@@ -157,13 +157,13 @@
     /**
      * Returns a string array with absolute minimum and maximum as [min,max].
      *
      * @param artifact The FLYSArtifact (not used in this implementation).
      * @param name The parameter name (not used in this implementation).
      *
      * @return a string array [min,max].
      */
     protected String[] getMinMaxDefaults(Artifact artifact, String name) {
-        FLYSArtifact flys = (FLYSArtifact) artifact;
+        D4EArtifact flys = (D4EArtifact) artifact;
 
         Object lower = getLower(flys);
         Object upper = getUpper(flys);
@@ -172,9 +172,9 @@
     }
 
 
-    protected abstract Object getLower(FLYSArtifact flys);
+    protected abstract Object getLower(D4EArtifact flys);
 
-    protected abstract Object getUpper(FLYSArtifact flys);
+    protected abstract Object getUpper(D4EArtifact flys);
 
     protected abstract String getType();
 }
@@ -134,13 +134,13 @@
      * [min,max].
      *
-     * @param artifact The FLYSArtifact that stores the parameter.
+     * @param artifact The D4EArtifact that stores the parameter.
      * @param name The name of the parameter for raw min/max value string.
      *
@@ -157,13 +157,13 @@
      * Returns a string array with absolute minimum and maximum as [min,max].
      *
-     * @param artifact The FLYSArtifact (not used in this implementation).
+     * @param artifact The D4EArtifact (not used in this implementation).
      * @param name The parameter name (not used in this implementation).
      *

http://dive4elements.wald.intevation.org